@@ -103,7 +103,7 @@ def restore(args):
     start_time = time.time()
     ssl, host, port = parse_url(args.host)
     print(f'Start at {datetime.datetime.now().isoformat()}')
-    restorer = Restorer(args.backup, host, port, args.key, args.connections, ssl, args.verify)
+    restorer = Restorer(args.backup, host, port, args.key, args.org, args.connections, ssl, args.verify)
     restorer.store_cases()
     if args.alerts:
         restorer.restore_alerts()
